@@ -59,7 +59,7 @@ extern unsigned long long Pagesize;
 extern unsigned long long Mmap_align;
 
 #if defined(__x86_64) || defined(_M_X64) || defined(__aarch64__) || \
-	defined(__riscv)
+	defined(__riscv) || defined(__loongarch64)
 #define CACHELINE_SIZE 64ULL
 #elif defined(__PPC64__)
 #define CACHELINE_SIZE 128ULL
