@@ -1,34 +1,5 @@
-/*
- * Copyright 2014-2019, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+/* SPDX-License-Identifier: BSD-3-Clause */
+/* Copyright 2014-2023, Intel Corporation */
 
 /*
  * libpmem.h -- definitions of libpmem entry points
@@ -56,6 +27,9 @@
 #define pmem_map_file pmem_map_fileU
 #define pmem_check_version pmem_check_versionU
 #define pmem_errormsg pmem_errormsgU
+
+#define WIN_DEPR_STR "Windows support is deprecated."
+#define WIN_DEPR_ATTR __declspec(deprecated(WIN_DEPR_STR))
 #endif
 
 #endif
@@ -82,29 +56,82 @@ extern "C" {
 void *pmem_map_file(const char *path, size_t len, int flags, mode_t mode,
 	size_t *mapped_lenp, int *is_pmemp);
 #else
+WIN_DEPR_ATTR
 void *pmem_map_fileU(const char *path, size_t len, int flags, mode_t mode,
 	size_t *mapped_lenp, int *is_pmemp);
+WIN_DEPR_ATTR
 void *pmem_map_fileW(const wchar_t *path, size_t len, int flags, mode_t mode,
 	size_t *mapped_lenp, int *is_pmemp);
 #endif
 
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 int pmem_unmap(void *addr, size_t len);
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 int pmem_is_pmem(const void *addr, size_t len);
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 void pmem_persist(const void *addr, size_t len);
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 int pmem_msync(const void *addr, size_t len);
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 int pmem_has_auto_flush(void);
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 void pmem_flush(const void *addr, size_t len);
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 void pmem_deep_flush(const void *addr, size_t len);
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 int pmem_deep_drain(const void *addr, size_t len);
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 int pmem_deep_persist(const void *addr, size_t len);
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 void pmem_drain(void);
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 int pmem_has_hw_drain(void);
 
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 void *pmem_memmove_persist(void *pmemdest, const void *src, size_t len);
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 void *pmem_memcpy_persist(void *pmemdest, const void *src, size_t len);
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 void *pmem_memset_persist(void *pmemdest, int c, size_t len);
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 void *pmem_memmove_nodrain(void *pmemdest, const void *src, size_t len);
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 void *pmem_memcpy_nodrain(void *pmemdest, const void *src, size_t len);
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 void *pmem_memset_nodrain(void *pmemdest, int c, size_t len);
 
 #define PMEM_F_MEM_NODRAIN	(1U << 0)
@@ -124,8 +151,17 @@ void *pmem_memset_nodrain(void *pmemdest, int c, size_t len);
 				PMEM_F_MEM_WB | \
 				PMEM_F_MEM_NOFLUSH)
 
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 void *pmem_memmove(void *pmemdest, const void *src, size_t len, unsigned flags);
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 void *pmem_memcpy(void *pmemdest, const void *src, size_t len, unsigned flags);
+#ifdef _WIN32
+WIN_DEPR_ATTR
+#endif
 void *pmem_memset(void *pmemdest, int c, size_t len, unsigned flags);
 
 /*
@@ -141,8 +177,10 @@ void *pmem_memset(void *pmemdest, int c, size_t len, unsigned flags);
 const char *pmem_check_version(unsigned major_required,
 	unsigned minor_required);
 #else
+WIN_DEPR_ATTR
 const char *pmem_check_versionU(unsigned major_required,
 	unsigned minor_required);
+WIN_DEPR_ATTR
 const wchar_t *pmem_check_versionW(unsigned major_required,
 	unsigned minor_required);
 #endif
@@ -150,7 +188,9 @@ const wchar_t *pmem_check_versionW(unsigned major_required,
 #ifndef _WIN32
 const char *pmem_errormsg(void);
 #else
+WIN_DEPR_ATTR
 const char *pmem_errormsgU(void);
+WIN_DEPR_ATTR
 const wchar_t *pmem_errormsgW(void);
 #endif
 
