@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2018-2020, Intel Corporation */
+/* Copyright 2018-2022, Intel Corporation */
 
 /*
  * badblocks_none.c -- fake bad blocks functions
@@ -14,9 +14,10 @@
  * pmem2_badblock_context_new -- allocate and create a new bad block context
  */
 int
-pmem2_badblock_context_new(const struct pmem2_source *src,
-	struct pmem2_badblock_context **bbctx)
+pmem2_badblock_context_new(struct pmem2_badblock_context **bbctx,
+	const struct pmem2_source *src)
 {
+	SUPPRESS_UNUSED(bbctx, src);
 	return PMEM2_E_NOSUPP;
 }
 
@@ -27,6 +28,7 @@ void
 pmem2_badblock_context_delete(
 	struct pmem2_badblock_context **bbctx)
 {
+	SUPPRESS_UNUSED(bbctx);
 }
 
 /*
@@ -36,6 +38,8 @@ int
 pmem2_badblock_next(struct pmem2_badblock_context *bbctx,
 	struct pmem2_badblock *bb)
 {
+	SUPPRESS_UNUSED(bbctx, bb);
+
 	return PMEM2_E_NOSUPP;
 }
 
@@ -46,5 +50,6 @@ int
 pmem2_badblock_clear(struct pmem2_badblock_context *bbctx,
 			const struct pmem2_badblock *bb)
 {
+	SUPPRESS_UNUSED(bbctx, bb);
 	return PMEM2_E_NOSUPP;
 }
