@@ -1,11 +1,11 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2020, Intel Corporation */
+/* Copyright 2020-2022, Intel Corporation */
 
 /*
  * usc_ndctl.c -- pmem2 usc function for platforms using ndctl
  */
 #include <ndctl/libndctl.h>
-#include <ndctl/libdaxctl.h>
+#include <daxctl/libdaxctl.h>
 #include <sys/types.h>
 #include <sys/sysmacros.h>
 #include <fcntl.h>
@@ -23,6 +23,7 @@ int
 pmem2_source_device_usc(const struct pmem2_source *src, uint64_t *usc)
 {
 	LOG(3, "type %d, uid %p", src->type, usc);
+	PMEM2_ERR_CLR();
 
 	if (src->type == PMEM2_SOURCE_ANON) {
 		ERR("Anonymous source does not support unsafe shutdown count");
@@ -78,6 +79,8 @@ err:
 int
 pmem2_source_device_id(const struct pmem2_source *src, char *id, size_t *len)
 {
+	PMEM2_ERR_CLR();
+
 	struct ndctl_ctx *ctx;
 	struct ndctl_dimm *dimm;
 	int ret;
