@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2015-2021, Intel Corporation */
+/* Copyright 2015-2022, Intel Corporation */
 
 /*
  * heap.c -- heap implementation
@@ -15,6 +15,7 @@
 #include "memblock.h"
 #include "queue.h"
 #include "heap.h"
+#include "heap_layout.h"
 #include "out.h"
 #include "util.h"
 #include "sys_util.h"
@@ -93,7 +94,7 @@ struct heap_rt {
 	unsigned nlocks;
 
 	unsigned nzones;
-	unsigned zones_exhausted;
+	int *zone_reclaimed_map;
 };
 
 /*
@@ -807,6 +808,41 @@ heap_reclaim_zone_garbage(struct palloc_heap *heap, struct bucket *bucket,
 	}
 }
 
+/*
+ * heap_ensure_zone_reclaimed -- make sure that the specified zone has been
+ * already reclaimed.
+ */
+void
+heap_ensure_zone_reclaimed(struct palloc_heap *heap, uint32_t zone_id)
+{
+	int zone_reclaimed;
+	util_atomic_load_explicit32(&heap->rt->zone_reclaimed_map[zone_id],
+		&zone_reclaimed, memory_order_acquire);
+	if (zone_reclaimed)
+		return;
+
+	struct bucket *defb = heap_bucket_acquire(heap,
+		DEFAULT_ALLOC_CLASS_ID,
+		HEAP_ARENA_PER_THREAD);
+
+	struct zone *z = ZID_TO_ZONE(heap->layout, zone_id);
+	ASSERTeq(z->header.magic, ZONE_HEADER_MAGIC);
+
+	/* check a second time just to make sure no other thread was first */
+	util_atomic_load_explicit32(&heap->rt->zone_reclaimed_map[zone_id],
+		&zone_reclaimed, memory_order_acquire);
+	if (zone_reclaimed)
+		goto out;
+
+	util_atomic_store_explicit32(&heap->rt->zone_reclaimed_map[zone_id], 1,
+		memory_order_release);
+
+	heap_reclaim_zone_garbage(heap, defb, zone_id);
+
+out:
+	heap_bucket_release(defb);
+}
+
 /*
  * heap_populate_bucket -- (internal) creates volatile state of memory blocks
  */
@@ -815,11 +851,19 @@ heap_populate_bucket(struct palloc_heap *heap, struct bucket *bucket)
 {
 	struct heap_rt *h = heap->rt;
 
+	unsigned zone_id; /* first not reclaimed zone */
+	for (zone_id = 0; zone_id < h->nzones; ++zone_id) {
+		if (h->zone_reclaimed_map[zone_id] == 0)
+			break;
+	}
+
 	/* at this point we are sure that there's no more memory in the heap */
-	if (h->zones_exhausted == h->nzones)
+	if (zone_id == h->nzones)
 		return ENOMEM;
 
-	uint32_t zone_id = h->zones_exhausted++;
+	util_atomic_store_explicit32(&heap->rt->zone_reclaimed_map[zone_id], 1,
+		memory_order_release);
+
 	struct zone *z = ZID_TO_ZONE(heap->layout, zone_id);
 
 	/* ignore zone and chunk headers */
@@ -1562,6 +1606,13 @@ heap_boot(struct palloc_heap *heap, void *heap_start, uint64_t heap_size,
 		goto error_heap_malloc;
 	}
 
+	h->nzones = heap_max_zone(heap_size);
+	h->zone_reclaimed_map = Zalloc(sizeof(int) * h->nzones);
+	if (h->zone_reclaimed_map == NULL) {
+		err = ENOMEM;
+		goto err_reclaimed_map_malloc;
+	}
+
 	if ((err = arena_thread_assignment_init(&h->arenas.assignment,
 		Default_arenas_assignment_type)) != 0) {
 		goto error_assignment_init;
@@ -1581,10 +1632,6 @@ heap_boot(struct palloc_heap *heap, void *heap_start, uint64_t heap_size,
 		goto error_arenas_malloc;
 	}
 
-	h->nzones = heap_max_zone(heap_size);
-
-	h->zones_exhausted = 0;
-
 	h->nlocks = On_valgrind ? MAX_RUN_LOCKS_VG : MAX_RUN_LOCKS;
 	for (unsigned i = 0; i < h->nlocks; ++i)
 		util_mutex_init(&h->run_locks[i]);
@@ -1621,6 +1668,8 @@ error_arenas_malloc:
 error_alloc_classes_new:
 	arena_thread_assignment_fini(&h->arenas.assignment);
 error_assignment_init:
+	Free(h->zone_reclaimed_map);
+err_reclaimed_map_malloc:
 	Free(h);
 	heap->rt = NULL;
 error_heap_malloc:
@@ -1716,6 +1765,7 @@ heap_cleanup(struct palloc_heap *heap)
 
 	VALGRIND_DO_DESTROY_MEMPOOL(heap->layout);
 
+	Free(rt->zone_reclaimed_map);
 	Free(rt);
 	heap->rt = NULL;
 }
@@ -1841,56 +1891,6 @@ heap_check(void *heap_start, uint64_t heap_size)
 	return 0;
 }
 
-/*
- * heap_check_remote -- verifies if the heap of a remote pool is consistent
- *	and can be opened properly
- *
- * If successful function returns zero. Otherwise an error number is returned.
- */
-int
-heap_check_remote(void *heap_start, uint64_t heap_size, struct remote_ops *ops)
-{
-	if (heap_size < HEAP_MIN_SIZE) {
-		ERR("heap: invalid heap size");
-		return -1;
-	}
-
-	struct heap_layout *layout = heap_start;
-
-	struct heap_header header;
-	if (ops->read(ops->ctx, ops->base, &header, &layout->header,
-						sizeof(struct heap_header))) {
-		ERR("heap: obj_read_remote error");
-		return -1;
-	}
-
-	if (heap_verify_header(&header))
-		return -1;
-
-	struct zone *zone_buff = (struct zone *)Malloc(sizeof(struct zone));
-	if (zone_buff == NULL) {
-		ERR("heap: zone_buff malloc error");
-		return -1;
-	}
-	for (unsigned i = 0; i < heap_max_zone(heap_size); ++i) {
-		if (ops->read(ops->ctx, ops->base, zone_buff,
-				ZID_TO_ZONE(layout, i), sizeof(struct zone))) {
-			ERR("heap: obj_read_remote error");
-			goto out;
-		}
-
-		if (heap_verify_zone(zone_buff)) {
-			goto out;
-		}
-	}
-	Free(zone_buff);
-	return 0;
-
-out:
-	Free(zone_buff);
-	return -1;
-}
-
 /*
  * heap_zone_foreach_object -- (internal) iterates through objects in a zone
  */
