@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2015-2021, Intel Corporation */
+/* Copyright 2015-2022, Intel Corporation */
 
 /*
  * palloc.c -- implementation of pmalloc POSIX-like API
@@ -270,7 +270,8 @@ palloc_heap_action_exec(struct palloc_heap *heap,
 	SUPPRESS_UNUSED(heap);
 
 #ifdef DEBUG
-	if (act->m.m_ops->get_state(&act->m) == act->new_state) {
+	enum memblock_state s = act->m.m_ops->get_state(&act->m);
+	if (s == act->new_state || s == MEMBLOCK_STATE_UNKNOWN) {
 		ERR("invalid operation or heap corruption");
 		ASSERT(0);
 	}
@@ -616,6 +617,8 @@ palloc_defer_free_create(struct palloc_heap *heap, uint64_t off,
 	out->offset = off;
 	out->m = memblock_from_offset(heap, off);
 
+	heap_ensure_zone_reclaimed(heap, out->m.zone_id);
+
 	/*
 	 * For the duration of free we may need to protect surrounding
 	 * metadata from being modified.
@@ -1289,16 +1292,6 @@ palloc_heap_check(void *heap_start, uint64_t heap_size)
 	return heap_check(heap_start, heap_size);
 }
 
-/*
- * palloc_heap_check_remote -- verifies state of remote replica
- */
-int
-palloc_heap_check_remote(void *heap_start, uint64_t heap_size,
-	struct remote_ops *ops)
-{
-	return heap_check_remote(heap_start, heap_size, ops);
-}
-
 /*
  * palloc_heap_cleanup -- cleanups the volatile heap state
  */
