@@ -1,34 +1,5 @@
-/*
- * Copyright 2016-2019, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2016-2023, Intel Corporation */
 
 /*
  * replica.c -- groups all commands for replica manipulation
@@ -56,8 +27,8 @@
 #include "util.h"
 #include "uuid.h"
 #include "shutdown_state.h"
-#include "os_dimm.h"
-#include "badblock.h"
+#include "badblocks.h"
+#include "set_badblocks.h"
 
 /*
  * check_flags_sync -- (internal) check if flags are supported for sync
@@ -160,7 +131,7 @@ replica_remove_part(struct pool_set *set, unsigned repn, unsigned partn,
 
 	/* if the part is a device dax, clear its bad blocks */
 	if (type == TYPE_DEVDAX && fix_bad_blocks &&
-	    os_dimm_devdax_clear_badblocks_all(part->path)) {
+	    badblocks_clear_all(part->path)) {
 		ERR("clearing bad blocks in device dax failed -- '%s'",
 			part->path);
 		errno = EIO;
@@ -511,26 +482,17 @@ replica_check_store_size(struct pool_set *set,
 	struct pool_replica *rep = set->replica[repn];
 	struct pmemobjpool pop;
 
-	if (rep->remote) {
-		memcpy(&pop.hdr, rep->part[0].hdr, sizeof(pop.hdr));
-		void *descr = (void *)((uintptr_t)&pop + POOL_HDR_SIZE);
-		if (Rpmem_read(rep->remote->rpp, descr, POOL_HDR_SIZE,
-			sizeof(pop) - POOL_HDR_SIZE, 0)) {
-			return -1;
-		}
-	} else {
-		/* round up map size to Mmap align size */
-		if (util_map_part(&rep->part[0], NULL,
-		    ALIGN_UP(sizeof(pop), rep->part[0].alignment),
-		    0, MAP_SHARED, 1)) {
-			return -1;
-		}
-
-		memcpy(&pop, rep->part[0].addr, sizeof(pop));
-
-		util_unmap_part(&rep->part[0]);
+	/* round up map size to Mmap align size */
+	if (util_map_part(&rep->part[0], NULL,
+		ALIGN_UP(sizeof(pop), rep->part[0].alignment),
+		0, MAP_SHARED, 1)) {
+		return -1;
 	}
 
+	memcpy(&pop, rep->part[0].addr, sizeof(pop));
+
+	util_unmap_part(&rep->part[0]);
+
 	void *dscp = (void *)((uintptr_t)&pop + sizeof(pop.hdr));
 
 	if (!util_checksum(dscp, OBJ_DSC_P_SIZE, &pop.checksum, 0,
@@ -577,25 +539,6 @@ check_and_open_poolset_part_files(struct pool_set *set,
 	for (unsigned r = 0; r < set->nreplicas; ++r) {
 		struct pool_replica *rep = set->replica[r];
 		struct replica_health_status *rep_hs = set_hs->replica[r];
-		if (rep->remote) {
-			if (util_replica_open_remote(set, r, 0)) {
-				LOG(1, "cannot open remote replica no %u", r);
-				return -1;
-			}
-
-			unsigned nlanes = REMOTE_NLANES;
-			int ret = util_poolset_remote_open(rep, r,
-					rep->repsize, 0,
-					rep->part[0].addr,
-					rep->resvsize, &nlanes);
-			if (ret) {
-				rep_hs->flags |= IS_BROKEN;
-				LOG(1, "remote replica #%u marked as BROKEN",
-					r);
-			}
-
-			continue;
-		}
 
 		for (unsigned p = 0; p < rep->nparts; ++p) {
 			const char *path = rep->part[p].path;
@@ -638,8 +581,6 @@ map_all_unbroken_headers(struct pool_set *set,
 	for (unsigned r = 0; r < set->nreplicas; ++r) {
 		struct pool_replica *rep = set->replica[r];
 		struct replica_health_status *rep_hs = set_hs->replica[r];
-		if (rep->remote)
-			continue;
 
 		for (unsigned p = 0; p < rep->nhdrs; ++p) {
 			/* skip broken parts */
@@ -664,13 +605,7 @@ unmap_all_headers(struct pool_set *set)
 {
 	LOG(3, "set %p", set);
 	for (unsigned r = 0; r < set->nreplicas; ++r) {
-		struct pool_replica *rep = set->replica[r];
 		util_replica_close(set, r);
-
-		if (rep->remote && rep->remote->rpp) {
-			Rpmem_close(rep->remote->rpp);
-			rep->remote->rpp = NULL;
-		}
 	}
 
 	return 0;
@@ -690,15 +625,6 @@ check_checksums_and_signatures(struct pool_set *set,
 		struct pool_replica *rep = REP(set, r);
 		struct replica_health_status *rep_hs = REP_HEALTH(set_hs, r);
 
-		/*
-		 * Checksums and signatures of remote replicas are checked
-		 * during opening them on the remote side by the rpmem daemon.
-		 * The local version of remote headers does not contain
-		 * such data.
-		 */
-		if (rep->remote)
-			continue;
-
 		for (unsigned p = 0; p < rep->nhdrs; ++p) {
 
 			/* skip broken parts */
@@ -763,7 +689,7 @@ replica_badblocks_recovery_file_save(struct part_health_status *part_hs)
 	/* save bad blocks */
 	for (unsigned i = 0; i < bbs->bb_cnt; i++) {
 		ASSERT(bbs->bbv[i].length != 0);
-		fprintf(recovery_file_name, "%llu %u\n",
+		fprintf(recovery_file_name, "%zu %zu\n",
 			bbs->bbv[i].offset, bbs->bbv[i].length);
 	}
 
@@ -827,7 +753,7 @@ replica_part_badblocks_recovery_file_read(struct part_health_status *part_hs)
 	unsigned long long min_offset = 0; /* minimum possible offset */
 
 	do {
-		if (fscanf(recovery_file, "%llu %u\n",
+		if (fscanf(recovery_file, "%zu %zu\n",
 				&bb.offset, &bb.length) < 2) {
 			LOG(1, "incomplete bad block recovery file -- '%s'",
 				path);
@@ -900,15 +826,6 @@ replica_badblocks_recovery_files_check(struct pool_set *set,
 		struct pool_replica *rep = set->replica[r];
 		struct replica_health_status *rep_hs = set_hs->replica[r];
 
-		if (rep->remote) {
-			/*
-			 * Bad blocks in remote replicas currently are fixed
-			 * during opening by removing and recreating
-			 * the whole remote replica.
-			 */
-			continue;
-		}
-
 		for (unsigned p = 0; p < rep->nparts; ++p) {
 			const char *path = PART(rep, p)->path;
 			struct part_health_status *part_hs = &rep_hs->part[p];
@@ -983,10 +900,6 @@ replica_badblocks_recovery_files_read(struct pool_set *set,
 		struct pool_replica *rep = set->replica[r];
 		struct replica_health_status *rep_hs = set_hs->replica[r];
 
-		/* XXX: not supported yet */
-		if (rep->remote)
-			continue;
-
 		for (unsigned p = 0; p < rep->nparts; ++p) {
 			const char *path = PART(rep, p)->path;
 			struct part_health_status *part_hs = &rep_hs->part[p];
@@ -1049,10 +962,6 @@ replica_badblocks_recovery_files_create_empty(struct pool_set *set,
 		struct pool_replica *rep = set->replica[r];
 		struct replica_health_status *rep_hs = set_hs->replica[r];
 
-		/* XXX: not supported yet */
-		if (rep->remote)
-			continue;
-
 		for (unsigned p = 0; p < rep->nparts; ++p) {
 			part_hs = &rep_hs->part[p];
 			path = PART(rep, p)->path;
@@ -1112,10 +1021,6 @@ replica_badblocks_recovery_files_save(struct pool_set *set,
 		struct pool_replica *rep = set->replica[r];
 		struct replica_health_status *rep_hs = set_hs->replica[r];
 
-		/* XXX: not supported yet */
-		if (rep->remote)
-			continue;
-
 		for (unsigned p = 0; p < rep->nparts; ++p) {
 			struct part_health_status *part_hs = &rep_hs->part[p];
 
@@ -1152,10 +1057,6 @@ replica_badblocks_get(struct pool_set *set,
 		struct pool_replica *rep = set->replica[r];
 		struct replica_health_status *rep_hs = set_hs->replica[r];
 
-		/* XXX: not supported yet */
-		if (rep->remote)
-			continue;
-
 		for (unsigned p = 0; p < rep->nparts; ++p) {
 			const char *path = PART(rep, p)->path;
 			struct part_health_status *part_hs = &rep_hs->part[p];
@@ -1167,7 +1068,7 @@ replica_badblocks_get(struct pool_set *set,
 			if (!exists)
 				continue;
 
-			int ret = os_badblocks_get(path, &part_hs->bbs);
+			int ret = badblocks_get(path, &part_hs->bbs);
 			if (ret < 0) {
 				ERR(
 					"!checking the pool part for bad blocks failed -- '%s'",
@@ -1216,10 +1117,6 @@ replica_badblocks_clear(struct pool_set *set,
 		struct pool_replica *rep = set->replica[r];
 		struct replica_health_status *rep_hs = set_hs->replica[r];
 
-		/* XXX: not supported yet */
-		if (rep->remote)
-			continue;
-
 		for (unsigned p = 0; p < rep->nparts; ++p) {
 			const char *path = PART(rep, p)->path;
 			struct part_health_status *part_hs = &rep_hs->part[p];
@@ -1248,7 +1145,7 @@ replica_badblocks_clear(struct pool_set *set,
 					rep_hs->flags |= HAS_CORRUPTED_HEADER;
 			}
 
-			ret = os_badblocks_clear(path, &part_hs->bbs);
+			ret = badblocks_clear(path, &part_hs->bbs);
 			if (ret < 0) {
 				LOG(1,
 					"clearing bad blocks in replica failed -- '%s'",
@@ -1472,9 +1369,6 @@ check_shutdown_state(struct pool_set *set,
 		struct replica_health_status *rep_hs = set_hs->replica[r];
 		struct pool_hdr *hdrp = HDR(rep, 0);
 
-		if (rep->remote)
-			continue;
-
 		if (hdrp == NULL) {
 			/* cannot verify shutdown state */
 			rep_hs->flags |= IS_BROKEN;
@@ -1484,19 +1378,11 @@ check_shutdown_state(struct pool_set *set,
 		struct shutdown_state curr_sds;
 		shutdown_state_init(&curr_sds, NULL);
 		for (unsigned p = 0; p < rep->nparts; ++p) {
-			const char *path = PART(rep, p)->path;
-			const int exists = util_file_exists(path);
-			if (exists < 0)
-				return -1;
-
-			/*
-			 * skip missing parts to avoid false positive shutdown
-			 * state failure detection
-			 */
-			if (!exists)
+			if (PART(rep, p)->fd < 0)
 				continue;
 
-			if (shutdown_state_add_part(&curr_sds, path, NULL)) {
+			if (shutdown_state_add_part(&curr_sds,
+					PART(rep, p)->fd, NULL)) {
 				rep_hs->flags |= IS_BROKEN;
 				break;
 			}
@@ -1901,11 +1787,7 @@ check_replica_sizes(struct pool_set *set, struct poolset_health_status *set_hs)
 
 		/* get the size of a pool in the replica */
 		ssize_t replica_pool_size;
-		if (REP(set, r)->remote)
-			/* XXX: no way to get the size of a remote pool yet */
-			replica_pool_size = (ssize_t)set->poolsize;
-		else
-			replica_pool_size = replica_get_pool_size(set, r);
+		replica_pool_size = replica_get_pool_size(set, r);
 
 		if (replica_pool_size < 0) {
 			LOG(1, "getting pool size from replica %u failed", r);
@@ -1958,17 +1840,6 @@ replica_read_features(struct pool_set *set,
 
 	for (unsigned r = 0; r < set->nreplicas; r++) {
 		struct pool_replica *rep = set->replica[r];
-		struct replica_health_status *rep_hs = set_hs->replica[r];
-
-		if (rep->remote) {
-			if (rep_hs->flags & IS_BROKEN)
-				continue;
-
-			struct pool_hdr *hdrp = rep->part[0].hdr;
-			memcpy(features, &hdrp->features, sizeof(*features));
-
-			return 0;
-		}
 
 		for (unsigned p = 0; p < rep->nparts; p++) {
 			struct pool_set_part *part = &rep->part[p];
@@ -2174,9 +2045,6 @@ replica_check_part_sizes(struct pool_set *set, size_t min_size)
 	LOG(3, "set %p, min_size %zu", set, min_size);
 	for (unsigned r = 0; r < set->nreplicas; ++r) {
 		struct pool_replica *rep = set->replica[r];
-		if (rep->remote != NULL)
-			/* skip remote replicas */
-			continue;
 
 		for (unsigned p = 0; p < rep->nparts; ++p) {
 			if (PART(rep, p)->filesize < min_size) {
@@ -2223,9 +2091,6 @@ replica_check_part_dirs(struct pool_set *set)
 	LOG(3, "set %p", set);
 	for (unsigned r = 0; r < set->nreplicas; ++r) {
 		struct pool_replica *rep = set->replica[r];
-		if (rep->remote != NULL)
-			/* skip remote replicas */
-			continue;
 
 		for (unsigned p = 0; p < rep->nparts; ++p) {
 			if (replica_check_local_part_dir(set, r, p))
@@ -2270,8 +2135,6 @@ replica_open_poolset_part_files(struct pool_set *set)
 {
 	LOG(3, "set %p", set);
 	for (unsigned r = 0; r < set->nreplicas; ++r) {
-		if (set->replica[r]->remote)
-			continue;
 		if (replica_open_replica_part_files(set, r)) {
 			LOG(1, "opening replica %u, part files failed", r);
 			goto err;
@@ -2327,13 +2190,7 @@ pmempool_syncU(const char *poolset, unsigned flags)
 	if (set->nreplicas == 1) {
 		ERR("no replica(s) found in the pool set");
 		errno = EINVAL;
-		goto err_close_file;
-	}
-
-	if (set->remote && util_remote_load()) {
-		ERR("remote replication not available");
-		errno = ENOTSUP;
-		goto err_close_file;
+		goto err_close_all;
 	}
 
 	/* sync all replicas */
@@ -2442,7 +2299,7 @@ pmempool_transformU(const char *poolset_src,
 	int fd_out = util_file_open(poolset_dst, NULL, 0, O_RDONLY);
 	if (fd_out < 0) {
 		ERR("cannot open destination poolset file");
-		goto err;
+		goto err_free_poolin;
 	}
 
 	enum del_parts_mode del = DO_NOT_DELETE_PARTS;
@@ -2465,16 +2322,6 @@ pmempool_transformU(const char *poolset_src,
 		goto err_free_poolout;
 	}
 
-	/* load remote library if needed */
-	if (set_in->remote && util_remote_load()) {
-		ERR("remote replication not available");
-		goto err_free_poolout;
-	}
-	if (set_out->remote && util_remote_load()) {
-		ERR("remote replication not available");
-		goto err_free_poolout;
-	}
-
 	del = is_dry_run(flags) ? DO_NOT_DELETE_PARTS : DELETE_CREATED_PARTS;
 
 	/* transform poolset */
