@@ -1,34 +1,5 @@
-/*
- * Copyright 2016-2019, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2016-2022, Intel Corporation */
 
 /*
  * transform.c -- a module for poolset transforming
@@ -96,9 +67,6 @@ check_if_part_used_once(struct pool_set *set, unsigned repn, unsigned partn)
 	int ret = 0;
 	for (unsigned r = repn; r < set->nreplicas; ++r) {
 		struct pool_replica *repr = set->replica[r];
-		/* skip remote replicas */
-		if (repr->remote != NULL)
-			continue;
 
 		/* avoid superfluous comparisons */
 		unsigned i = (r == repn) ? partn + 1 : 0;
@@ -142,34 +110,6 @@ out:
 	return ret;
 }
 
-/*
- * check_if_remote_replica_used_once -- (internal) check if remote replica is
- *                                      used only once in the rest of the
- *                                      poolset
- */
-static int
-check_if_remote_replica_used_once(struct pool_set *set, unsigned repn)
-{
-	LOG(3, "set %p, repn %u", set, repn);
-	struct remote_replica *rep = REP(set, repn)->remote;
-	ASSERTne(rep, NULL);
-	for (unsigned r = repn + 1; r < set->nreplicas; ++r) {
-		/* skip local replicas */
-		if (REP(set, r)->remote == NULL)
-			continue;
-
-		struct remote_replica *repr = REP(set, r)->remote;
-		/* XXX: add comparing resolved addresses of the nodes */
-		if (strcmp(rep->node_addr, repr->node_addr) == 0 &&
-				strcmp(rep->pool_desc, repr->pool_desc) == 0) {
-			ERR("remote replica %u is used multiple times", repn);
-			errno = EINVAL;
-			return -1;
-		}
-	}
-	return 0;
-}
-
 /*
  * check_paths -- (internal) check if directories for part files exist
  *                and if paths for part files do not repeat in the poolset
@@ -180,17 +120,12 @@ check_paths(struct pool_set *set)
 	LOG(3, "set %p", set);
 	for (unsigned r = 0; r < set->nreplicas; ++r) {
 		struct pool_replica *rep = set->replica[r];
-		if (rep->remote != NULL) {
-			if (check_if_remote_replica_used_once(set, r))
+		for (unsigned p = 0; p < rep->nparts; ++p) {
+			if (replica_check_local_part_dir(set, r, p))
 				return -1;
-		} else {
-			for (unsigned p = 0; p < rep->nparts; ++p) {
-				if (replica_check_local_part_dir(set, r, p))
-					return -1;
 
-				if (check_if_part_used_once(set, r, p))
-					return -1;
-			}
+			if (check_if_part_used_once(set, r, p))
+				return -1;
 		}
 	}
 	return 0;
@@ -290,24 +225,16 @@ compare_replicas(struct pool_replica *r1, struct pool_replica *r2)
 {
 	LOG(3, "r1 %p, r2 %p", r1, r2);
 	LOG(4, "r1->nparts: %u, r2->nparts: %u", r1->nparts, r2->nparts);
-	/* both replicas are local */
-	if (r1->remote == NULL && r2->remote == NULL) {
-		if (r1->nparts != r2->nparts)
-			return 1;
 
-		for (unsigned p = 0; p < r1->nparts; ++p) {
-			if (compare_parts(&r1->part[p], &r2->part[p]))
-				return 1;
-		}
-		return 0;
+	if (r1->nparts != r2->nparts)
+		return 1;
+
+	for (unsigned p = 0; p < r1->nparts; ++p) {
+		if (compare_parts(&r1->part[p], &r2->part[p]))
+			return 1;
 	}
-	/* both replicas are remote */
-	if (r1->remote != NULL && r2->remote != NULL) {
-		return strcmp(r1->remote->node_addr, r2->remote->node_addr) ||
-			strcmp(r1->remote->pool_desc, r2->remote->pool_desc);
-	}
-	/* a remote and a local replicas */
-	return 1;
+
+	return 0;
 }
 
 /*
@@ -524,10 +451,6 @@ do_added_parts_exist(struct pool_set *set,
 
 		struct pool_replica *rep = REP(set, r);
 
-		/* skip remote replicas */
-		if (rep->remote)
-			continue;
-
 		for (unsigned p = 0; p < rep->nparts; ++p) {
 			/* check if part file exists */
 			int oerrno = errno;
@@ -557,17 +480,11 @@ delete_replicas(struct pool_set *set, struct poolset_compare_status *set_s)
 	for (unsigned r = 0; r < set->nreplicas; ++r) {
 		struct pool_replica *rep = REP(set, r);
 		if (replica_counterpart(r, set_s) == UNDEF_REPLICA) {
-			if (!rep->remote) {
-				if (util_replica_close_local(rep, r,
-						DELETE_ALL_PARTS))
-					return -1;
-			} else {
-				if (util_replica_close_remote(rep, r,
-						DELETE_ALL_PARTS))
-					return -1;
+			if (util_replica_close_local(rep, r,
+					DELETE_ALL_PARTS))
+				return -1;
 			}
 		}
-	}
 	return 0;
 }
 
