@@ -1,34 +1,5 @@
-/*
- * Copyright 2015-2020, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2015-2021, Intel Corporation */
 
 /*
  * obj_heap.c -- unit test for heap
@@ -374,7 +345,7 @@ test_heap(void)
 		heap_get_bestfit_block(heap, b_def, &blocks[i]);
 		UT_ASSERT(blocks[i].block_off == 0);
 	}
-	heap_bucket_release(heap, b_def);
+	heap_bucket_release(b_def);
 
 	struct memory_block old_run = {0, 0, 1, 0};
 	struct memory_block new_run = {0, 0, 0, 0};
@@ -396,7 +367,7 @@ test_heap(void)
 		UT_ASSERTne(new_run.size_idx, 0);
 	} while (old_run.block_off != new_run.block_off);
 
-	heap_bucket_release(heap, b_run);
+	heap_bucket_release(b_run);
 
 	stats_delete(pop, s);
 	UT_ASSERT(heap_check(heap_start, heap_size) == 0);
@@ -468,7 +439,7 @@ test_heap_with_size()
 	VALGRIND_DO_MAKE_MEM_DEFINED(ptr, s);
 	memset(ptr, 0xc, s);
 
-	heap_bucket_release(heap, b_def);
+	heap_bucket_release(b_def);
 
 	UT_ASSERT(heap_check(heap_start, heap_size) == 0);
 	heap_cleanup(heap);
@@ -519,7 +490,7 @@ test_recycler(void)
 		DEFAULT_ALLOC_CLASS_ID,
 		HEAP_ARENA_PER_THREAD);
 	UT_ASSERT(heap_get_bestfit_block(heap, b, &m) == 0);
-	heap_bucket_release(heap, b);
+	heap_bucket_release(b);
 
 	int ret;
 
@@ -540,10 +511,10 @@ test_recycler(void)
 	memblock_rebuild_state(&pop->heap, &mrun);
 	memblock_rebuild_state(&pop->heap, &mrun2);
 
-	ret = recycler_put(r, &mrun,
+	ret = recycler_put(r,
 		recycler_element_new(&pop->heap, &mrun));
 	UT_ASSERTeq(ret, 0);
-	ret = recycler_put(r, &mrun2,
+	ret = recycler_put(r,
 		recycler_element_new(&pop->heap, &mrun2));
 	UT_ASSERTeq(ret, 0);
 
@@ -578,16 +549,16 @@ test_recycler(void)
 	struct memory_block mrun4_ret = MEMORY_BLOCK_NONE;
 	mrun4_ret.size_idx = 1;
 
-	ret = recycler_put(r, &mrun,
+	ret = recycler_put(r,
 		recycler_element_new(&pop->heap, &mrun));
 	UT_ASSERTeq(ret, 0);
-	ret = recycler_put(r, &mrun2,
+	ret = recycler_put(r,
 		recycler_element_new(&pop->heap, &mrun2));
 	UT_ASSERTeq(ret, 0);
-	ret = recycler_put(r, &mrun3,
+	ret = recycler_put(r,
 		recycler_element_new(&pop->heap, &mrun3));
 	UT_ASSERTeq(ret, 0);
-	ret = recycler_put(r, &mrun4,
+	ret = recycler_put(r,
 		recycler_element_new(&pop->heap, &mrun4));
 	UT_ASSERTeq(ret, 0);
 
@@ -608,7 +579,7 @@ test_recycler(void)
 	struct memory_block mrun5 = {1, 0, 1, 0};
 	memblock_rebuild_state(&pop->heap, &mrun5);
 
-	ret = recycler_put(r, &mrun5,
+	ret = recycler_put(r,
 		recycler_element_new(&pop->heap, &mrun5));
 	UT_ASSERTeq(ret, 0);
 
