@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2019-2021, Intel Corporation */
+/* Copyright 2019-2022, Intel Corporation */
 
 /*
  * pmem2_map.c -- pmem2_map unittests
@@ -11,6 +11,7 @@
 #include "pmem2_utils.h"
 #include "source.h"
 #include "map.h"
+#include "mover.h"
 #include "out.h"
 #include "pmem2.h"
 #include "unittest.h"
@@ -50,6 +51,12 @@ prepare_map(struct pmem2_map **map_ptr,
 	UT_ASSERTne(mh, NULL);
 	UT_ASSERTne(GetLastError(), ERROR_ALREADY_EXISTS);
 
+	struct vdm *vdm;
+	mover_new(map, &vdm);
+	UT_ASSERTne(map, NULL);
+	map->custom_vdm = true;
+	map->vdm = vdm;
+
 	map->addr = MapViewOfFileEx(mh,
 		FILE_MAP_ALL_ACCESS,
 		HIDWORD(cfg->offset),
@@ -91,6 +98,12 @@ prepare_map(struct pmem2_map **map_ptr,
 	struct pmem2_map *map = malloc(sizeof(*map));
 	UT_ASSERTne(map, NULL);
 
+	struct vdm *vdm;
+	mover_new(map, &vdm);
+	UT_ASSERTne(map, NULL);
+	map->custom_vdm = true;
+	map->vdm = vdm;
+
 	UT_ASSERTeq(src->type, PMEM2_SOURCE_FD);
 	map->addr = mmap(NULL, cfg->length, proto, flags,
 		src->value.fd, offset);
