@@ -1,6 +1,6 @@
 #!../env.py
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright 2020-2022, Intel Corporation
+# Copyright 2020-2023, Intel Corporation
 #
 
 import testframework as t
@@ -115,6 +115,14 @@ class Pmem2MemExt(t.Test):
         ret = tools.Tools(ctx.env, ctx.build).cpufd()
         self.check_arch(ctx.variant(), ret.returncode)
 
+        # XXX all tests with VARIANT_AVX512F are disabled under Valgrind
+        # until the issue https://github.com/pmem/pmdk/issues/5640 is fixed.
+        # "win32" `if`` is related to unknown `is not None` by Windows Python
+        if not sys.platform.startswith('win32') and ctx.valgrind is not None:
+            if ctx.valgrind.tool.name != "NONE":
+                if ctx.variant() == VARIANT_AVX512F:
+                    raise futils.Skip("AVX512F unavailable under Valigrind")
+
     def check_arch(self, variant, available_arch):
         if variant == VARIANT_MOVDIR64B:
             if available_arch < MOVDIR64B:
