@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2015-2020, Intel Corporation */
+/* Copyright 2015-2023, Intel Corporation */
 
 /*
  * memcpy_common.c -- common part for tests doing a persistent memcpy
@@ -9,6 +9,25 @@
 #include "memcpy_common.h"
 #include "valgrind_internal.h"
 
+/*
+ * do_persist - performs selected persist function
+ */
+static void
+do_persist(persist_fn p, char *ptr, size_t len)
+{
+	p(ptr, len);
+}
+
+/*
+ * do_memcpy_s - performs selected memcpy function
+ */
+static void *
+do_memcpy_s(memcpy_fn m, char *ptr1, char *ptr2,
+			size_t len, unsigned flags)
+{
+	return m(ptr1, ptr2, len, flags);
+}
+
 /*
  * do_memcpy: Worker function for memcpy
  *
@@ -18,7 +37,6 @@
  * dest. Use the non pmem version of the memset/memcpy commands
  * so as not to introduce any possible side affects.
  */
-
 void
 do_memcpy(int fd, char *dest, int dest_off, char *src, int src_off,
     size_t bytes, size_t mapped_len, const char *file_name, memcpy_fn fn,
@@ -29,26 +47,28 @@ do_memcpy(int fd, char *dest, int dest_off, char *src, int src_off,
 
 	memset(buf, 0, bytes);
 	memset(dest, 0, bytes);
-	persist(dest, bytes);
+	do_persist(persist, dest, bytes);
 	memset(src, 0, bytes);
-	persist(src, bytes);
+	do_persist(persist, src, bytes);
 
 	memset(src, 0x5A, bytes / 4);
-	persist(src, bytes / 4);
+	do_persist(persist, src, bytes / 4);
 	memset(src + bytes / 4, 0x46, bytes / 4);
-	persist(src + bytes / 4, bytes / 4);
+	do_persist(persist, src + bytes / 4, bytes / 4);
 
 	/* dest == src */
-	ret = fn(dest + dest_off, dest + dest_off, bytes / 2, flags);
+	ret = do_memcpy_s(fn, dest + dest_off, dest + dest_off,
+		bytes / 2, flags);
 	UT_ASSERTeq(ret, dest + dest_off);
 	UT_ASSERTeq(*(char *)(dest + dest_off), 0);
 
 	/* len == 0 */
-	ret = fn(dest + dest_off, src, 0, flags);
+	ret = do_memcpy_s(fn, dest + dest_off, src, 0, flags);
 	UT_ASSERTeq(ret, dest + dest_off);
 	UT_ASSERTeq(*(char *)(dest + dest_off), 0);
 
-	ret = fn(dest + dest_off, src + src_off, bytes / 2, flags);
+	ret = do_memcpy_s(fn, dest + dest_off, src + src_off,
+		bytes / 2, flags);
 	if (flags & PMEM2_F_MEM_NOFLUSH)
 		VALGRIND_DO_PERSIST((dest + dest_off), bytes / 2);
 	UT_ASSERTeq(ret, dest + dest_off);
