@@ -1,13 +1,13 @@
 #!../env.py
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright 2020, Intel Corporation
+# Copyright 2020-2021, Intel Corporation
 #
 
 
 import testframework as t
 
 
-@t.require_ndctl
+@t.require_ndctl()
 @t.windows_exclude
 class TEST0(t.Test):
     test_type = t.Short
@@ -18,7 +18,7 @@ class TEST0(t.Test):
                  testfile1, 0)
 
 
-@t.require_ndctl
+@t.require_ndctl()
 @t.windows_exclude
 @t.require_devdax(t.DevDax('devdax', alignment=2 * t.MiB))
 class TEST1(t.Test):
