@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: BSD-3-Clause
-/* Copyright 2020, Intel Corporation */
+/* Copyright 2020-2022, Intel Corporation */
 
 /*
  * cpufd.c -- cpu feature detector - tool to detect
@@ -9,6 +9,7 @@
  *	1 - SSE2 available
  *	2 - AVX available
  *	3 - AVX512 available
+ *	4 - MOVDIR64B available
  */
 
 #include "cpu.h"
@@ -25,5 +26,8 @@ main(int argc, char *argv[])
 	if (is_cpu_avx512f_present())
 		ret = 3;
 
+	if (is_cpu_movdir64b_present())
+		ret = 4;
+
 	return ret;
 }
