@@ -1,11 +1,12 @@
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright 2019-2020, Intel Corporation
+# Copyright 2019-2021, Intel Corporation
 
 """Test framework utilities."""
 
 from os.path import join, abspath
 import os
 import sys
+import subprocess as sp
 
 import consts as c
 import configurator
@@ -38,13 +39,15 @@ def get_lib_dir(ctx):
         return c.RELEASE_LIBDIR
 
 
-def get_example_path(ctx, libname, name):
+def get_example_path(ctx, libname, name, dirname=None):
     """
     Get the path to the example binary.
     Paths to examples differ on Windows and Unix systems. On Windows,
     the example binaries have a specific name: ex_libname_name.
     On Unix systems, the example binaries are located in the catalog
     "lib + libname/name" and have the same name as .c file.
+    If that is not the case, dirname optional argument can be used to
+    specify different catalog for the example binary- "lib + libname/dirname".
     """
     if sys.platform == 'win32':
         binname = '_'.join(['ex', libname, name])
@@ -53,8 +56,10 @@ def get_example_path(ctx, libname, name):
         else:
             return abspath(join(c.WIN_RELEASE_BUILDDIR, 'examples', binname))
     else:
+        if dirname is None:
+            dirname = name
         return abspath(join(c.ROOTDIR, '..', 'examples', 'lib' + libname,
-                            name, name))
+                            dirname, name))
 
 
 def tail(file, n):
@@ -81,9 +86,18 @@ def count(file, substring):
     return content.count(substring)
 
 
+def run_command(cmd, errormsg=""):
+    proc = sp.Popen(cmd, shell=True, stdout=sp.PIPE, stderr=sp.STDOUT)
+    out = proc.communicate()
+
+    if proc.returncode != 0:
+        raise Fail("failed to execute command {}: {}".format(cmd, errormsg))
+    return out[0]
+
+
 class Color:
     """
-    Set the font color. This functionality relies on ANSI espace sequences
+    Set the font color. This functionality relies on ANSI escape sequences
     and is currently disabled for Windows.
     """
     if sys.platform != 'win32':
