@@ -1,5 +1,5 @@
 /* SPDX-License-Identifier: BSD-3-Clause */
-/* Copyright 2014-2020, Intel Corporation */
+/* Copyright 2014-2023, Intel Corporation */
 
 /*
  * unittest.h -- the mundane stuff shared by all unit tests
@@ -61,7 +61,6 @@
 #include <libpmemlog.h>
 #include <libpmemobj.h>
 #include <libpmempool.h>
-#include <libpmemset.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -750,6 +749,57 @@ if (off != sizeof(type))\
 		STR(type), last, STR(type), sizeof(type), off);\
 } while (0)
 
+struct markers {
+	size_t markers_no;
+	char **markers;
+};
+
+/*
+ * get_markers - parse markers from pmreorder
+ *		(which are passed in the form of char array
+ *		e.g."MARKER.BEGIN|MARKER.END")
+ *		and return struct including list of markers
+ *		and information about its quantity
+ */
+static inline struct markers *
+get_markers(const char *input)
+{
+	if (!input)
+		return NULL;
+
+	struct markers *log = (struct markers *)MALLOC(sizeof(struct markers));
+	const char *delim = "|";
+	char *tmp = STRDUP(input);
+
+	log->markers_no = 1;
+	for (char *s = tmp; *s != '\0'; s++)
+		if (*s == *delim)
+			log->markers_no++;
+	log->markers = (char **)MALLOC(log->markers_no * sizeof(char *));
+
+	unsigned i = 0;
+	char *token;
+	char *rest = NULL;
+
+	for (token = strtok_r(tmp, delim, &rest); token != NULL;
+		token = strtok_r(NULL, delim, &rest)) {
+		log->markers[i] = STRDUP(token);
+		i++;
+	}
+
+	FREE(tmp);
+	return log;
+}
+
+static inline void
+delete_markers(struct markers *log)
+{
+	for (size_t i = 0; i < log->markers_no; i++)
+		FREE(log->markers[i]);
+	FREE(log->markers);
+	FREE(log);
+}
+
 /*
  * AddressSanitizer
  */
