@@ -1,34 +1,5 @@
-/*
- * Copyright 2016-2019, Intel Corporation
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- *     * Redistributions of source code must retain the above copyright
- *       notice, this list of conditions and the following disclaimer.
- *
- *     * Redistributions in binary form must reproduce the above copyright
- *       notice, this list of conditions and the following disclaimer in
- *       the documentation and/or other materials provided with the
- *       distribution.
- *
- *     * Neither the name of the copyright holder nor the names of its
- *       contributors may be used to endorse or promote products derived
- *       from this software without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- */
+// SPDX-License-Identifier: BSD-3-Clause
+/* Copyright 2016-2020, Intel Corporation */
 
 /*
  * util_ctl.c -- tests for the control module
@@ -713,11 +684,11 @@ test_ctl_arg_parsers()
 static void
 test_fault_injection(struct pool *pop)
 {
-	if (!common_fault_injection_enabled())
+	if (!core_fault_injection_enabled())
 		return;
 
 	UT_ASSERTne(pop, NULL);
-	common_inject_fault_at(PMEM_MALLOC, 1, "ctl_parse_args");
+	core_inject_fault_at(PMEM_MALLOC, 1, "ctl_parse_args");
 
 	test_config_written = 0;
 	int ret = ctl_load_config_from_string(pop->ctl, pop,
@@ -743,24 +714,23 @@ main(int argc, char *argv[])
 
 	test_ctl_global_namespace(NULL);
 
-	struct pool *pop = malloc(sizeof(pop));
+	struct pool pop;
 
-	pop->ctl = ctl_new();
+	pop.ctl = ctl_new();
 
 	test_ctl_global_namespace(NULL);
 
-	CTL_REGISTER_MODULE(pop->ctl, debug);
+	CTL_REGISTER_MODULE(pop.ctl, debug);
 
-	test_ctl_global_namespace(pop);
+	test_ctl_global_namespace(&pop);
 
-	test_fault_injection(pop);
-	test_ctl_parser(pop);
-	test_string_config(pop);
-	test_file_config(pop);
+	test_fault_injection(&pop);
+	test_ctl_parser(&pop);
+	test_string_config(&pop);
+	test_file_config(&pop);
 	test_ctl_arg_parsers();
 
-	ctl_delete(pop->ctl);
-	free(pop);
+	ctl_delete(pop.ctl);
 
 	common_fini();
 
