@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # SPDX-License-Identifier: BSD-3-Clause
-# Copyright 2016-2022, Intel Corporation
+# Copyright 2016-2023, Intel Corporation
 
 #
 # install-valgrind.sh - installs valgrind for persistent memory
@@ -12,6 +12,7 @@ OS=$1
 
 install_upstream_from_distro() {
   case "$OS" in
+    rockylinux) dnf install -y valgrind ;;
     fedora) dnf install -y valgrind ;;
     ubuntu) apt-get install -y --no-install-recommends valgrind ;;
     *) return 1 ;;
@@ -34,8 +35,8 @@ install_upstream_3_16_1() {
 install_custom-pmem_from_source() {
   git clone https://github.com/pmem/valgrind.git
   cd valgrind
-  # valgrind v3.19 with pmemcheck
-  git checkout 541e1c3d22b34769ad29fa75ab29cce2a65bfa91
+  # valgrind v3.20 + fixes for ppc64; 01.02.2023
+  git checkout c0abd814ff955c7eb2850bd3827167a6b084e975
   ./autogen.sh
   ./configure
   make -j$(nproc)
@@ -46,7 +47,6 @@ install_custom-pmem_from_source() {
 
 ARCH=$(uname -m)
 case "$ARCH" in
-  ppc64le) install_upstream_3_16_1 ;;
   aarch64) install_upstream_3_16_1 ;;
   *) install_custom-pmem_from_source ;;
 esac
